# Welcome to Scholar Network

This package is intended for people wanting to scrape Google Scholar
to build graph networks of Google Scholar authors and identify network
connections as opportunities for collaboration.

## Features

1. Selenium based web scraping
2. Poetry based dependency management
3. Basic Graph algorithms and metrics
